;; git clone git@github.com:cl-test-grid/cl-test-grid.git
(pushnew "path/to/cl-test-grid/" asdf:*central-registry* :test #'equal)

(ql:quickload :test-grid-storage :verbose t)
(ql:quickload :test-grid-reporting :verbose t)

(defpackage #:abcl-reports
  (:use :cl)
  (:import-from #:test-grid-reporting
                #:list-results
                #:subset                
                #:print-compiler-diff
                #:print-pivot
                #:lisp
                #:libname
                #:lib-world
                #:contact-email
                #:results-cell-printer))
(in-package #:abcl-reports)

;;; Retrieving test results from online storage ;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(defun snapshot-file (file-name)
  (asdf:system-relative-pathname :test-grid-storage
                                 file-name))

;; We use results from two storages: "main" were results of all releases
;; lisps are published, and "abcl" where we store results of ABCL
;; pre-release tests.
(defparameter *r* (tg-storage:make-replica "abcl" (snapshot-file "db-abcl.lisp")))
(defparameter *rm* (tg-storage:make-replica "main" (snapshot-file "db-main.lisp")))

;; Incrementally synchronize the local replicas with the online DBs.
;; First time it loads the full db and may take a minute or two;
;; you may observe progress in the REPL buffer.
;; Next time synchronizations only fetch new changes and are performed faster.
(tg-storage:sync *r*)
(tg-storage:sync *rm*)

;; access the test results database stored in the replica
(defparameter *db* (tg-data:join-dbs (tg-storage:data *r*)
                                     (tg-storage:data *rm*)))
;; Now *DB* stores a data structure documented here:
;; https://github.com/cl-test-grid/cl-test-grid/tree/master/data

;;; Generating reports ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;
;;; The API is explained here:
;;; https://github.com/cl-test-grid/cl-test-grid/tree/master/reporting

(defparameter *all-results* (list-results *db*))

(print-compiler-diff "abcl/abcl-diff3.html"
                     *all-results*
                     "quicklisp 2013-03-12"
                     "abcl-1.1.1-fasl39-linux-x86"
                     ;"abcl-1.2.0-dev-svn-14300-fasl39-linux-x86"
                     "abcl-1.2.0-dev-svn-14436-fasl40-linux-x86"
                     ;"quicklisp 2013-03-12"
                     )

(print-compiler-diff "abcl/abcl-diff4.html"
                     *all-results*
                     "quicklisp 2013-02-17"
                     "abcl-1.1.1-fasl39-linux-x86"
                     "abcl-1.1.1-fasl39-linux-x86"
                     "quicklisp 2013-03-12"
                     )

(print-compiler-diff "abcl/abcl-diff5.html"
                     *all-results*
                     "quicklisp 2013-03-12"
                     "abcl-1.2.0-dev-svn-14436-fasl40-linux-x86"
                     "abcl-1.2.0-dev-svn-14445-fasl40-linux-x86")

(print-compiler-diff "abcl/abcl-diff6.html"
                     *all-results*
                     "quicklisp 2013-03-12"
                     "abcl-1.1.1-fasl39-linux-x86"
                     "abcl-1.2.0-dev-svn-14445-fasl40-linux-x86")

(print-compiler-diff "abcl/abcl-diff7.html"
                     *all-results*
                     "quicklisp 2013-03-12"
                     "abcl-1.2.0-dev-svn-14445-fasl40-linux-x86"
                     "abcl-1.2.0-dev-svn-14451-fasl40-linux-x86")

(print-compiler-diff "abcl/abcl-diff8.html"
                     *all-results*
                     "quicklisp 2013-03-12"
                     "abcl-1.1.1-fasl39-linux-x86"
                     "abcl-1.2.0-dev-svn-14451-fasl40-linux-x86")


(print-compiler-diff "abcl/abcl-diff8.html"
                     *all-results*
                     "quicklisp 2013-03-12"
                     "abcl-1.1.1-fasl39-linux-x86"
                     "abcl-1.2.0-dev-svn-14451-fasl40-linux-x86")

(print-compiler-diff "abcl/abcl-diff9.html"
                     *all-results*
                     "quicklisp 2013-03-12"
                     "abcl-1.2.0-dev-svn-14451-fasl40-linux-x86"
                     "abcl-1.2.0-dev-svn-14452-fasl40-linux-x86")

;; load failures report
(tg-rep::print-load-failures "abcl/abcl-1-2-0-load-failures.html"
                             *all-results*
                             "abcl-1.2.0-dev-svn-14451-fasl40-linux-x86"
                             "quicklisp 2013-03-12")
